@@ -1,20 +1,20 @@
 import logging
 import os
 import sys
+from typing import Optional
 
 import fire
 from ruamel.yaml import YAML
-from typing import Optional
 
-from cfg4py import init, enable_logging, envar
+from cfg4py import enable_logging, envar, init
 
 enable_logging()
 
 
 class Command:
-
     def __init__(self):
-        self.resource_path = os.path.normpath(os.path.join(os.path.dirname(__file__), 'resources/'))
+        self.resource_path = os.path.normpath(
+            os.path.join(os.path.dirname(__file__), 'resources/'))
         self.yaml = YAML(typ='safe')  # default, if not specfied, is 'rt' (round-trip)
         self.yaml.default_flow_style = False
 
@@ -24,8 +24,8 @@ class Command:
         self.transformed = self._transform()
 
     def build(self, config_dir: str):
-        """
-        Compile configuration files into a python class file, which is used by IDE's auto-complete function
+        """Compile configuration files into a python class file, which is used by IDE's
+        auto-complete function
 
         Args:
             config_dir: The folder where your configuration files located
@@ -39,7 +39,8 @@ class Command:
 
         count = 0
         for f in os.listdir(config_dir):
-            if f.startswith("default") or f.startswith("dev") or f.startswith("test") or f.startswith("production"):
+            if f.startswith("default") or f.startswith("dev") or f.startswith(
+                    "test") or f.startswith("production"):
                 print(f"found {f}")
                 count += 1
 
@@ -55,10 +56,11 @@ class Command:
 
             init(config_dir)
             sys.path.insert(0, config_dir)
-            # noinspection PyUnresolvedReferences
-            from cfg4py_auto_gen import Config
-            print(f"Config file is built with success and saved at {os.path.join(config_dir, 'cfg4py_auto_gen')}")
-        except Exception as e: # pragma: no cover
+            from cfg4py_auto_gen import Config  # type: ignore # noqa
+            output_file = f"{os.path.join(config_dir, 'cfg4py_auto_gen')}"
+            msg = f"Config file is built with success and saved at {output_file}"
+            print(msg)
+        except Exception as e:  # pragma: no cover
             logging.exception(e)
             print("Config file built failure.")
 
@@ -68,8 +70,10 @@ class Command:
 
         if os.path.exists(dst):
             for f in os.listdir(dst):
+                msg = f"The folder already contains {f}, please choose clean one."
+
                 if f in ['defaults.yaml', 'dev.yaml', 'test.yaml', 'production.yaml']:
-                    print(f"The folder provided already contains {f}, please choose clean one.")
+                    print(msg)
                     return None
             return dst
         else:
@@ -83,8 +87,7 @@ class Command:
                 return None
 
     def scaffold(self, dst: Optional[str]):
-        """
-        Creates initial configuration files based on our choices.
+        """Creates initial configuration files based on our choices.
         Args:
             dst:
 
@@ -113,7 +116,8 @@ class Command:
         50 - mongodb/pymongo (gh://mongodb/mongo-python-driver)
         """
         print(prompt)
-        chooses = input("Please choose flavors by index, separated each by a comma(,):\n")
+        chooses = input(
+            "Please choose flavors by index, separated each by a comma(,):\n")
         flavors = {}
         mapping = {
             "0": "logging",
@@ -137,14 +141,16 @@ class Command:
                 continue
 
         with open(os.path.join(dst, "defaults.yaml"), 'w') as f:
-            f.writelines("#auto generated by Cfg4Py: https://github.com/jieyu-tech/cfg4py\n")
+            f.writelines(
+                "#auto generated by Cfg4Py: https://github.com/jieyu-tech/cfg4py\n")
             yaml.dump(flavors, f)
 
         print(f"Cfg4Py has generated the following files under {dst}:")
         print("defaults.yaml")
         for name in ['dev.yaml', 'test.yaml', 'production.yaml']:
             with open(os.path.join(dst, name), 'w') as f:
-                f.writelines("#auto generated by Cfg4Py: https://github.com/jieyu-tech/cfg4py\n")
+                f.writelines(
+                    "#auto generated by Cfg4Py: https://github.com/jieyu-tech/cfg4py\n")
                 print(name)
 
         with open(os.path.join(dst, "defaults.yaml"), 'r') as f:
@@ -185,7 +191,8 @@ class Command:
         :param usage
         """
 
-        if what is None or ((what not in self.templates) and what not in self.transformed):
+        if what is None or (
+                (what not in self.templates) and what not in self.transformed):
             return self._show_supported_config()
 
         usage_key = f"{what}_usage"
@@ -205,14 +212,17 @@ class Command:
     def set_server_role(self):
         print("please add the following line into your .bashrc:\n")
         print(f"export {envar}=DEV\n")
-        print("You need to change DEV to TEST | PRODUCTION according to its actual role accordingly")
+        msg = "You need to change DEV to TEST | PRODUCTION according to its actual role\
+         accordingly"
+        print(msg)
+
 
 def main():
-    cmd = Command() # pragma: no cover
-    fire.Fire({ # pragma: no cover
-        "build":           cmd.build,
-        "scaffold":        cmd.scaffold,
-        "hint":            cmd.hint,
+    cmd = Command()  # pragma: no cover
+    fire.Fire({  # pragma: no cover
+        "build": cmd.build,
+        "scaffold": cmd.scaffold,
+        "hint": cmd.hint,
         "set_server_role": cmd.set_server_role
     })
 
